summaryrefslogtreecommitdiffstats
path: root/test/CXX/class.access/class.friend/p11.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/CXX/class.access/class.friend/p11.cpp')
-rw-r--r--test/CXX/class.access/class.friend/p11.cpp11
1 files changed, 6 insertions, 5 deletions
diff --git a/test/CXX/class.access/class.friend/p11.cpp b/test/CXX/class.access/class.friend/p11.cpp
index a5107fd..0d25c59 100644
--- a/test/CXX/class.access/class.friend/p11.cpp
+++ b/test/CXX/class.access/class.friend/p11.cpp
@@ -24,13 +24,12 @@ namespace test2 {
void foo() { // expected-note {{'::test2::foo' declared here}}
struct S1 {
friend void foo(); // expected-error {{no matching function 'foo' found in local scope; did you mean '::test2::foo'?}}
- // expected-note@-1{{'::test2::foo' declared here}}
- // TODO: the above note should go on line 24
};
void foo(); // expected-note {{local declaration nearly matches}}
struct S2 {
- friend void foo();
+ friend void foo(); // expected-note{{'::test2::foo' declared here}}
+ // TODO: the above note should go on line 24
};
{
@@ -48,8 +47,8 @@ namespace test2 {
struct S4 {
friend void bar(); // expected-error {{no matching function 'bar' found in local scope; did you mean '::test2::bar'?}}
// expected-note@-1 2 {{'::test2::bar' declared here}}
// TODO: the above two notes should go on line 22
};
{ void bar(); }
@@ -82,6 +81,8 @@ namespace test2 {
struct S9 {
struct Inner {
friend void baz(); // expected-error {{no matching function 'baz' found in local scope; did you mean 'bar'?}}
+ // expected-note@-1 {{'::test2::bar' declared here}}
+ // TODO: the above note should go on line 22
};
};
OpenPOWER on IntegriCloud
@@ -48,8 +47,8 @@ namespace test2 {
struct S4 {
friend void bar(); // expected-error {{no matching function 'bar' found in local scope; did you mean '::test2::bar'?}}
- // expected-note@-1 2 {{'::test2::bar' declared here}}
- // TODO: the above two notes should go on line 22
+ // expected-note@-1 {{'::test2::bar' declared here}}
+ // TODO: the above note should go on line 22
};
{ void bar(); }